==> spread-5.0.0.54-py3-none-any.whl: spread-5.0.0.54.data/data/spread/dashboard/static/local/la_buttons.js <==
var currentId;
var currentLA;
var maxId=0;

const client = init_client(
    broker,
    function onConnect() {
        console.log('MQTT Connected');
        client.subscribe(PROJECT, {});
        client.subscribe(TOPIC + '+', {});
    },
    function onMessage(topic, message) {
        console.log('Recv: ', topic, message);
        if (topic === PROJECT) {
            client.unsubscribe(topic);
            onProject(message);
        } else if (topic.startsWith(TOPIC)) {
            const arr = topic.split('/');
            updatePreset(arr[arr.length - 1], message);
        } else if (topic.startsWith(LA_STATE.split('+')[0])) {
            updateLA(message);
        }
    }
);

function onProject(message) {
    for (var eng of message['engineries']) {
        if (eng['type'] === 'LightingArea') {
            var maxIndex = -1;
            if (eng.hasOwnProperty('recipe') && eng.recipe.hasOwnProperty('ingredients')) {
                for (var recipe of eng.recipe.ingredients) {
                    if (recipe.hasOwnProperty('type') &&
                        recipe.hasOwnProperty('index') &&
                        recipe.type === 'Button') {
                        maxIndex = Math.max(recipe.index, maxIndex);
                    }
                }
            }
            if (maxIndex >= 0) {
                var la = document.createElement('label');
                la.id = eng['id'];
                la.setAttribute('max-index', maxIndex);
                la.textContent = eng['name'];

                $('#lightingareas').find(' table').each(function (index, node) {
                    node.insertRow().insertCell().appendChild(la);
                });
                la.addEventListener('click', selectLA);
            }
        }
    }
}

function selectLA(e) {
    if (currentLA) {
        client.unsubscribe(LA_STATE.replace('+', currentLA));
    }
    currentLA = e.target.id;
    markSelected(e.target);
    $('#presets').hide();
    $('#recipes').show();
    $('#recipes tbody').children().remove();
    const selector = document.createElement('select');
    selector[0] = new Option('');
    $('#announcement table').find('tr td label').each(function (i, label) {
        selector[selector.options.length] = new Option(label.textContent, label.id);
    });
    $('#recipes table').each(function (_, table) {
        for (var i=0; i <= parseInt(e.target.getAttribute('max-index')); i++) {
            const row = table.insertRow();
            row.id = 'index-'+i;
            row.insertCell().textContent = 'index '+i;
            row.insertCell().appendChild(selector.cloneNode(true));
        }
    });

    client.subscribe(LA_STATE.replace('+', currentLA));
}

function saveLA() {
    var message = {
        value: [],
    };
    $('#recipes table select').each(function (index, selector) {
        if (selector.value) {
            message.value.push({
                index: index,
                preset: parseInt(selector.value)
            });
        }
    });

    client.send(LA_SET.replace('+', currentLA), JSON.stringify(message));
}

function updateLA(message) {
    for (var recipe of message.value) {
        if (recipe.hasOwnProperty('index') && recipe.hasOwnProperty('preset')) {
            $('#index-'+recipe.index).find('select').each(function (i, selector) {
                selector.value = recipe.preset;
            });
        }
    }
}

function selectPreset(e) {
    if (currentId) {
        client.unsubscribe(TOPIC + currentId + '/#', {});
    }
    currentId = e.target.id;
    markSelected(e.target);
    $('#presets').show();
    $('#recipes').hide();
    $('.handler').find(' form').each(function (index, node) {
        node.remove();
    });
    client.subscribe(TOPIC + currentId + '/#', {});
}

function updatePreset(id, message) {
    maxId = Math.max(id, maxId);

    const $announcement = $('#announcement');
    const items = $announcement.find('label[id=' + id + ']');

    if (message === '') {
        items[0].remove();
        if (id === currentId) {
            var labels = $announcement.find(' table label').each(function (index, node) {
                node.click();
                return false;
            });

            if (labels.length === 0) {
                currentId = undefined;
                $('#presets').hide();
            }
        }
    } else {
        if (message.hasOwnProperty('name')) {
            if (items.length === 0) {
                // create announcement
                var item = document.createElement('label');
                item.id = id;
                item.textContent = message.name;

                $announcement.find(' table').each(function (index, node) {
                    node.insertRow().insertCell().appendChild(item);
                });
                item.addEventListener('click', selectPreset);

                if (currentId === undefined) {
                    item.click();
                }
            } else {
                // update announcement
                $(items[0]).text(message.name);
            }

            // sort announcement
            const tbody = $announcement.find(' table tbody');
            var rows = tbody.children().detach().get();
            rows.sort(function (a, b) {
                return $(a).find(" label").text().localeCompare($(b).find(" label").text());
            });
            tbody.append(rows);

            // select first announcement
            if (id === currentId) {
                $('#preset-form').find('input[name=name]').each(function (index, node) {
                    node.value = message.name;
                });
            }
        }
        if (message.hasOwnProperty('isToggle')) {
            if (id === currentId) {
                $('#preset-form').find('input[name=isToggle]').each(function (index, node) {
                    node.checked = message.isToggle;
                    node.dispatchEvent(new Event('change'));
                });
            }
        }
        if (message.hasOwnProperty('handlers')) {
            if (id === currentId) {
                $('.handler').each(function (index, handler) {
                    $(handler).find(' form').each(function (index, node) {
                        node.remove();
                    });
                    if (message.handlers.length > 0) {
                        for (var i = 0; i < message.handlers[index].length; i++) {
                            handler.insertBefore(
                                createAction(message.handlers[index][i]),
                                handler.children[handler.childElementCount - 1]
                            );
                        }
                    }
                });
            }
        }
    }
}

function savePreset() {

    function form2data(form, formData) {
        formData = formData ? formData : {};

        function getValue(index, input) {
            if (input.style.display !== 'none' && input.value !== '') {
                if (input.type === 'checkbox') {
                    formData[input.name] = input.checked;
                } else {
                    formData[input.name] = isNaN(parseInt(input.value)) ? input.value : parseInt(input.value);
                }
            }
        }
        $(form).find("input").each(getValue);
        $(form).find("select").each(getValue);

        return formData;
    }

    var result = form2data($('#preset-form')[0], {handlers: [[], []]});
    var valid = true;

    $('.handlers').find('.handler').each(function (index, handler) {
        $(handler).find(' form').each(function (_, form) {
            var _valid = form.reportValidity();
            if (_valid) {
                result.handlers[index].push(form2data(form));
            } else {
                console.log('invalid', form);
            }

            valid = valid && _valid;
        });
    });
    if (valid) {
        console.log('Send: ', TOPIC + currentId, result);
        client.send(TOPIC + currentId, JSON.stringify(result), 0, true);
    }
}

function markSelected(target) {
    $(document).find(' .selected').toggleClass('selected');
    $(target).toggleClass('selected');
}

function checkToggled(chb) {
    if (chb.checked) {
        $('#handler_1').show()
    } else {
        $('#handler_1').hide()
    }
}

function checkCommand(selector) {
    $(selector).parents(' form').each(function (index, node) {
        const sceneSelector = $(node).find(' select[name=scene]');
        sceneSelector[0].required = selector.value === 'Scene';
        if (selector.value === 'Scene') {
            sceneSelector.show();
        } else {
            sceneSelector.hide();
        }

        const levelInput = $(node).find(' input[name=level]');
        levelInput[0].required = selector.value === 'Level';
        if (selector.value === 'Level') {
            levelInput.show();
        } else {
            levelInput.hide();
        }
    });
}

function createAction(data) {
    var div = document.createElement('form');
    div.innerHTML = ACTION;
    setInputValue(div, 'event', data.event);
    setInputValue(div, 'command', data.command);
    setInputValue(div, 'scene', data.scene);
    setInputValue(div, 'level', data.level);
    setInputValue(div, 'setLightingArea', data.setLightingArea || '');
    setInputValue(div, 'stopTuning', data.stopTuning);
    return div;
}

function removeAction(e) {
    $(e.target).parents(" form").remove();
}

function addAction(handler) {
    handler.insertBefore(
        createAction({}),
        handler.children[handler.childElementCount - 1]
    );
}

function setInputValue(owner, name, value) {
    $(owner).find('[name=' + name + ']').each(function (index, input) {
        if (input.type === 'checkbox') {
            input.checked = value;
        } else {
            input.value = value;
        }

        input.dispatchEvent(new Event('change', {target: input}));
    });
}

function addPreset() {
    currentId = undefined;
    client.send(TOPIC+(maxId+1), JSON.stringify({name: 'New Preset'}), 0, true);
}

function removePreset() {
    client.send(TOPIC+currentId, '', 0, true);
}

const ACTION =
    '<p class="add-remove remove" onclick="removeAction(event);"><span class="glyphicon glyphicon-remove"></span></p>\n' +
    '<form><table>\n' +
    '    <tr><td>Событие</td>\n' +
    '        <td><select name="event" required>\n' +
    '            <option value="ShortPress">Short press</option>\n' +
    '            <option value="DoublePress">Double press</option>\n' +
    '            <option value="LongPressStart">Long press start</option>\n' +
    '            <option value="LongPressStop">Long press stop</option>\n' +
    '            <option value="LongPressRepeat">Long press repeat</option>\n' +
    '            <option value="ButtonStuck">Buttons stuck</option>\n' +
    '            <option value="ButtonFree">Button free</option>\n' +
    '            <option value="ButtonPressed">Button pressed</option>\n' +
    '            <option value="ButtonReleased">Button released</option>\n' +
    '        </select></td></tr>\n' +
    '    <tr><td>Команда</td>\n' +
    '        <td>\n'+
    '            <select name="command" onchange="checkCommand(this);">\n' +
    '                <option value="EmulateOccupancy">Emulate occupancy</option>\n' +
    '                <option value="EmulateVacancy">Emulate vacancy</option>\n' +
    '                <option value="LastLevel">Last level</option>\n' +
    '                <option value="Level">Level</option>\n' +
    '                <option value="MaxLevel">Max level</option>\n' +
    '                <option value="MinLevel">Min level</option>\n' +
    '                <option value="Off">Off</option>\n' +
    '                <option value="Scene">Scene</option>\n' +
    '                <option value="Up">Up</option>\n' +
    '                <option value="Down">Down</option>\n' +
    '                <option value="StepUp">Step up</option>\n' +
    '                <option value="StepDown">Step down</option>\n' +
    '                <option value="OnAndStepUp">On and step up</option>\n' +
    '                <option value="StepDownAndOff">Step down and off</option>\n' +
    '            </select>\n' +
    '           <input type="number" name="level" min="0" max="100" style="width: 50px">\n' +
    '           <select name="scene">\n' +
    '                <option value="0">0</option>\n' +
    '                <option value="1">1</option>\n' +
    '                <option value="2">2</option>\n' +
    '                <option value="3">3</option>\n' +
    '                <option value="4">4</option>\n' +
    '                <option value="5">5</option>\n' +
    '                <option value="6">6</option>\n' +
    '                <option value="7">7</option>\n' +
    '                <option value="8">8</option>\n' +
    '                <option value="9">9</option>\n' +
    '                <option value="10">10</option>\n' +
    '                <option value="11">11</option>\n' +
    '                <option value="12">12</option>\n' +
    '                <option value="13">13</option>\n' +
    '                <option value="14">14</option>\n' +
    '                <option value="15">15</option>\n' +
    '                <option value="255">255</option>\n' +
    '            </select>\n' +
    '        </td></tr>\n' +
    '    <tr><td>Световая зона</td>\n' +
    '        <td><select name="setLightingArea">\n' +
    '            <option value=""></option>\n' +
    '            <option value="On">On</option>\n' +
    '            <option value="Off">Off</option>\n' +
    '        </select></td></tr>\n' +
    '    <tr><td style="max-width: 150px; word-wrap:break-word">Без подкрутки</td>\n' +
    '        <td><input type="checkbox" name="stopTuning"></td></tr>\n' +
    '</table></form>';

==> spread-5.3.0.5-py3-none-any.whl: spread-5.3.0.5.data/data/spread/dashboard/static/local/la_buttons.js <==
var currentId;
var currentLA;
var maxId=0;

const client = init_client(
    broker,
    function onConnect() {
        console.log('MQTT Connected');
        client.subscribe(PROJECT, {});
        client.subscribe(TOPIC + '+', {});
    },
    function onMessage(topic, message) {
        console.log('Recv: ', topic, message);
        if (topic === PROJECT) {
            client.unsubscribe(topic);
            onProject(message);
        } else if (topic.startsWith(TOPIC)) {
            const arr = topic.split('/');
            updatePreset(arr[arr.length - 1], message);
        } else if (topic.startsWith(LA_STATE.split('+')[0])) {
            updateLA(message);
        }
    }
);

function onProject(message) {
    for (var eng of message['engineries']) {
        if (eng['type'] === 'LightingArea') {
            var maxIndex = -1;
            if (eng.hasOwnProperty('recipe') && eng.recipe.hasOwnProperty('ingredients')) {
                for (var recipe of eng.recipe.ingredients) {
                    if (recipe.hasOwnProperty('type') &&
                        recipe.hasOwnProperty('index') &&
                        recipe.type === 'Button') {
                        maxIndex = Math.max(recipe.index, maxIndex);
                    }
                }
            }
            if (maxIndex >= 0) {
                var la = document.createElement('label');
                la.id = eng['id'];
                la.setAttribute('max-index', maxIndex);
                la.textContent = eng['name'];

                $('#lightingareas').find(' table').each(function (index, node) {
                    node.insertRow().insertCell().appendChild(la);
                });
                la.addEventListener('click', selectLA);
            }
        }
    }
}

function selectLA(e) {
    if (currentLA) {
        client.unsubscribe(LA_STATE.replace('+', currentLA));
    }
    currentLA = e.target.id;
    markSelected(e.target);
    $('#presets').hide();
    $('#recipes').show();
    $('#recipes tbody').children().remove();
    const selector = document.createElement('select');
    selector[0] = new Option('');
    $('#announcement table').find('tr td label').each(function (i, label) {
        selector[selector.options.length] = new Option(label.textContent, label.id);
    });
    $('#recipes table').each(function (_, table) {
        for (var i=0; i <= parseInt(e.target.getAttribute('max-index')); i++) {
            const row = table.insertRow();
            row.id = 'index-'+i;
            row.insertCell().textContent = 'index '+i;
            row.insertCell().appendChild(selector.cloneNode(true));
        }
    });

    client.subscribe(LA_STATE.replace('+', currentLA));
}

function saveLA() {
    var message = {
        value: [],
    };
    $('#recipes table select').each(function (index, selector) {
        if (selector.value) {
            message.value.push({
                index: index,
                preset: parseInt(selector.value)
            });
        }
    });

    client.send(LA_SET.replace('+', currentLA), JSON.stringify(message));
}

function updateLA(message) {
    for (var recipe of message.value) {
        if (recipe.hasOwnProperty('index') && recipe.hasOwnProperty('preset')) {
            $('#index-'+recipe.index).find('select').each(function (i, selector) {
                selector.value = recipe.preset;
            });
        }
    }
}

function selectPreset(e) {
    if (currentId) {
        client.unsubscribe(TOPIC + currentId + '/#', {});
    }
    currentId = e.target.id;
    markSelected(e.target);
    $('#presets').show();
    $('#recipes').hide();
    $('.handler').find(' form').each(function (index, node) {
        node.remove();
    });
    client.subscribe(TOPIC + currentId + '/#', {});
}

function updatePreset(id, message) {
    maxId = Math.max(id, maxId);

    const $announcement = $('#announcement');
    const items = $announcement.find('label[id=' + id + ']');

    if (message === '') {
        items[0].remove();
        if (id === currentId) {
            var labels = $announcement.find(' table label').each(function (index, node) {
                node.click();
                return false;
            });

            if (labels.length === 0) {
                currentId = undefined;
                $('#presets').hide();
            }
        }
    } else {
        if (message.hasOwnProperty('name')) {
            if (items.length === 0) {
                // create announcement
                var item = document.createElement('label');
                item.id = id;
                item.textContent = message.name;

                $announcement.find(' table').each(function (index, node) {
                    node.insertRow().insertCell().appendChild(item);
                });
                item.addEventListener('click', selectPreset);

                if (currentId === undefined) {
                    item.click();
                }
            } else {
                // update announcement
                $(items[0]).text(message.name);
            }

            // sort announcement
            const tbody = $announcement.find(' table tbody');
            var rows = tbody.children().detach().get();
            rows.sort(function (a, b) {
                return $(a).find(" label").text().localeCompare($(b).find(" label").text());
            });
            tbody.append(rows);

            // select first announcement
            if (id === currentId) {
                $('#preset-form').find('input[name=name]').each(function (index, node) {
                    node.value = message.name;
                });
            }
        }
        if (message.hasOwnProperty('isToggle')) {
            if (id === currentId) {
                $('#preset-form').find('input[name=isToggle]').each(function (index, node) {
                    node.checked = message.isToggle;
                    node.dispatchEvent(new Event('change'));
                });
            }
        }
        if (message.hasOwnProperty('handlers')) {
            if (id === currentId) {
                $('.handler').each(function (index, handler) {
                    $(handler).find(' form').each(function (index, node) {
                        node.remove();
                    });
                    if (message.handlers.length > 0) {
                        for (var i = 0; i < message.handlers[index].length; i++) {
                            handler.insertBefore(
                                createAction(message.handlers[index][i]),
                                handler.children[handler.childElementCount - 1]
                            );
                        }
                    }
                });
            }
        }
    }
}

function savePreset() {

    function form2data(form, formData) {
        formData = formData ? formData : {};

        function getValue(index, input) {
            if (input.style.display !== 'none' && input.value !== '') {
                if (input.type === 'checkbox') {
                    formData[input.name] = input.checked;
                } else {
                    formData[input.name] = input.value;
                    if (parseInt(input.value) == input.value) {
                        formData[input.name] = parseInt(input.value);
                    }
                }
            }
        }
        $(form).find("input").each(getValue);
        $(form).find("select").each(getValue);

        return formData;
    }

    var result = form2data($('#preset-form')[0], {handlers: [[], []]});
    var valid = true;

    $('.handlers').find('.handler').each(function (index, handler) {
        $(handler).find(' form').each(function (_, form) {
            var _valid = form.reportValidity();
            if (_valid) {
                result.handlers[index].push(form2data(form));
            } else {
                console.log('invalid', form);
            }

            valid = valid && _valid;
        });
    });
    if (valid) {
        console.log('Send: ', TOPIC + currentId, result);
        client.send(TOPIC + currentId, JSON.stringify(result), 0, true);
    }
}

function markSelected(target) {
    $(document).find(' .selected').toggleClass('selected');
    $(target).toggleClass('selected');
}

function checkToggled(chb) {
    if (chb.checked) {
        $('#handler_1').show()
    } else {
        $('#handler_1').hide()
    }
}

function checkCommand(selector) {
    $(selector).parents(' form').each(function (index, node) {
        const sceneSelector = $(node).find(' select[name=scene]');
        sceneSelector[0].required = selector.value === 'Scene';
        if (selector.value === 'Scene') {
            sceneSelector.show();
        } else {
            sceneSelector.hide();
        }

        const levelInput = $(node).find(' input[name=level]');
        levelInput[0].required = selector.value === 'Level';
        if (selector.value === 'Level') {
            levelInput.show();
        } else {
            levelInput.hide();
        }
    });
}

function createAction(data) {
    var div = document.createElement('form');
    div.innerHTML = ACTION;
    setInputValue(div, 'event', data.event);
    setInputValue(div, 'command', data.command);
    setInputValue(div, 'scene', data.scene);
    setInputValue(div, 'level', data.level);
    setInputValue(div, 'setLightingArea', data.setLightingArea || '');
    setInputValue(div, 'stopTuning', data.stopTuning);
    return div;
}

function removeAction(e) {
    $(e.target).parents(" form").remove();
}

function addAction(handler) {
    handler.insertBefore(
        createAction({}),
        handler.children[handler.childElementCount - 1]
    );
}

function setInputValue(owner, name, value) {
    $(owner).find('[name=' + name + ']').each(function (index, input) {
        if (input.type === 'checkbox') {
            input.checked = value;
        } else {
            input.value = value;
        }

        input.dispatchEvent(new Event('change', {target: input}));
    });
}

function addPreset() {
    currentId = undefined;
    client.send(TOPIC+(maxId+1), JSON.stringify({name: 'New Preset'}), 0, true);
}

function removePreset() {
    client.send(TOPIC+currentId, '', 0, true);
}

const ACTION =
    '<p class="add-remove remove" onclick="removeAction(event);"><span class="glyphicon glyphicon-remove"></span></p>\n' +
    '<form><table>\n' +
    '    <tr><td>' + gettext("local_la_buttons_event") + '</td>\n' +
    '        <td><select name="event" required>\n' +
    '            <option value="ShortPress">Short press</option>\n' +
    '            <option value="DoublePress">Double press</option>\n' +
    '            <option value="LongPressStart">Long press start</option>\n' +
    '            <option value="LongPressStop">Long press stop</option>\n' +
    '            <option value="LongPressRepeat">Long press repeat</option>\n' +
    '            <option value="ButtonStuck">Buttons stuck</option>\n' +
    '            <option value="ButtonFree">Button free</option>\n' +
    '            <option value="ButtonPressed">Button pressed</option>\n' +
    '            <option value="ButtonReleased">Button released</option>\n' +
    '        </select></td></tr>\n' +
    '    <tr><td>' + gettext("local_la_buttons_command") + '</td>\n' +
    '        <td>\n'+
    '            <select name="command" onchange="checkCommand(this);">\n' +
    '                <option value="EmulateOccupancy">Emulate occupancy</option>\n' +
    '                <option value="EmulateVacancy">Emulate vacancy</option>\n' +
    '                <option value="LastLevel">Last level</option>\n' +
    '                <option value="Level">Level</option>\n' +
    '                <option value="MaxLevel">Max level</option>\n' +
    '                <option value="MinLevel">Min level</option>\n' +
    '                <option value="Off">Off</option>\n' +
    '                <option value="Scene">Scene</option>\n' +
    '                <option value="Up">Up</option>\n' +
    '                <option value="Down">Down</option>\n' +
    '                <option value="StepUp">Step up</option>\n' +
    '                <option value="StepDown">Step down</option>\n' +
    '                <option value="OnAndStepUp">On and step up</option>\n' +
    '                <option value="StepDownAndOff">Step down and off</option>\n' +
    '            </select>\n' +
    '           <input type="number" name="level" min="0" max="100" style="width: 50px">\n' +
    '           <select name="scene">\n' +
    '                <option value="0">0</option>\n' +
    '                <option value="1">1</option>\n' +
    '                <option value="2">2</option>\n' +
    '                <option value="3">3</option>\n' +
    '                <option value="4">4</option>\n' +
    '                <option value="5">5</option>\n' +
    '                <option value="6">6</option>\n' +
    '                <option value="7">7</option>\n' +
    '                <option value="8">8</option>\n' +
    '                <option value="9">9</option>\n' +
    '                <option value="10">10</option>\n' +
    '                <option value="11">11</option>\n' +
    '                <option value="12">12</option>\n' +
    '                <option value="13">13</option>\n' +
    '                <option value="14">14</option>\n' +
    '                <option value="15">15</option>\n' +
    '                <option value="255">255</option>\n' +
    '            </select>\n' +
    '        </td></tr>\n' +
    '    <tr><td>' + gettext("local_la_buttons_la") + '</td>\n' +
    '        <td><select name="setLightingArea">\n' +
    '            <option value=""></option>\n' +
    '            <option value="On">On</option>\n' +
    '            <option value="Off">Off</option>\n' +
    '        </select></td></tr>\n' +
    '    <tr><td style="max-width: 150px; word-wrap:break-word">' + gettext("local_la_buttons_no") + '</td>\n' +
    '        <td><input type="checkbox" name="stopTuning"></td></tr>\n' +
    '</table></form>';
